<?php
/**
*
* @package VC
* @copyright (c) 2011 AdwertWay
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (!class_exists('phpbb_default_captcha'))
{
	// we need the classic captcha code for tracking solutions and attempts
	include($phpbb_root_path . 'includes/captcha/plugins/captcha_abstract.' . $phpEx);
}

require($phpbb_root_path . 'includes/captcha/plugins/advertway_captcha_lib.' . $phpEx);
/**
* @package VC
*/
class phpbb_advertway extends phpbb_default_captcha
{
	var $images = array();
	var $challenge;
	var $solution;
	var $awcaptcha;

	function init($type)
	{
		global $config, $db, $user;
		$user->add_lang('captcha_advertway');
		parent::init($type);
		$this->challenge = request_var('captcha_challenge_code', '');
		$this->solution = request_var('captcha_solution', '');
	}

	function get_instance()
	{
		$instance =& new phpbb_advertway();
		return $instance;
	}

	function is_available()
	{
		global $config, $user;

		$user->add_lang('captcha_advertway');
		return (isset($config['advertway_publickey']) && !empty($config['advertway_publickey']) && 
			isset($config['advertway_privatekey']) && !empty($config['advertway_privatekey']));
	}

	function get_name()
	{
		return 'CAPTCHA_ADVERTWAY';
	}

	function get_class_name()
	{
		return 'phpbb_advertway';
	}

	function has_config()
	{
		return true;
	}
	
	function acp_page($id, &$module)
	{
		global $config, $db, $template, $user;

		$captcha_vars = array(
			'advertway_publickey'			=> 'ADVERTWAY_PUBLICKEY',
			'advertway_privatekey'			=> 'ADVERTWAY_PRIVATEKEY',
			'advertway_register'			=> 'ADVERTWAY_REGISTER',
			'advertway_login'			    => 'ADVERTWAY_LOGIN',
			'advertway_post'			    => 'ADVERTWAY_POST',
			'advertway_sendpassword'	    => 'ADVERTWAY_SENDPASSWORD'
		);

		$module->tpl_name = 'captcha_advertway_acp';
		$module->page_title = 'ACP_VC_SETTINGS';
		$form_key = 'acp_captcha';
		add_form_key($form_key);

		$submit = request_var('submit', '');

		if ($submit && check_form_key($form_key))
		{
			$captcha_vars = array_keys($captcha_vars);
			foreach ($captcha_vars as $captcha_var)
			{
				$value = request_var($captcha_var, '');
				set_config($captcha_var, $value);
			}
			trigger_error($user->lang['CONFIG_UPDATED'] . adm_back_link($module->u_action));
		}
		else if ($submit)
		{
			trigger_error($user->lang['FORM_INVALID'] . adm_back_link($module->u_action));
		}
		else
		{
			foreach ($captcha_vars as $captcha_var => $template_var)
			{
				$var = (isset($_REQUEST[$captcha_var])) ? request_var($captcha_var, '') : ((isset($config[$captcha_var])) ? $config[$captcha_var] : '');
				$template->assign_var($template_var, $var);
			}

			$template->assign_vars(array(
				'CAPTCHA_PREVIEW'	=> $this->get_demo_template($id),
				'CAPTCHA_NAME'		=> $this->get_class_name(),
			));

		}
	}

	function get_template()
	{
		global $config, $user, $template, $phpEx, $phpbb_root_path;
        $mode= request_var('mode', '');
        $available = true;
		
		if ($mode=='register' && !$config['advertway_register']) 
		{		   
		    $available = false;
		}
		
		if ($mode=='login' && !$config['advertway_login']) 
		{		    
		    $available = false;
		}
		
		if ($mode=='post' && !$config['advertway_post']) 
		{		    
		    $available = false;
		}
		
		if ($mode=='reply' && !$config['advertway_post']) 
		{		    
		    $available = false;
		}
		
		if ($mode=='sendpassword' && !$config['advertway_sendpassword']) 
		{		    
		    $available = false;
		}
		
		if($this->is_solved())
		{
			return false;
		}
		
		// Implicit else
        $html= '';
		if ($this->is_available()) 
		{		
    		$this->awcaptcha = new AdvertWayApi($config['advertway_publickey'], $config['advertway_privatekey']);
            $html = $this->awcaptcha->getCaptchaWidget();
		}
		
		$template->assign_vars(array(
			'S_ADVERTWAY_AVAILABLE'		    => $this->is_available(),
			'S_ADVERTWAY_AVAILABLE_HERE'    => $available,
			'ADVERTWAY_HTML'			    => $html,
			'S_TYPE'			            => $this->type,
            'S_CONFIRM_CODE'                => true,
		));
		
		return 'captcha_advertway.html';
	}

	function get_demo_template($id)
	{
		global $config, $user, $template, $phpbb_admin_path, $phpEx;
        
		$html= '';
		if ($this->is_available())
		{
    		$this->awcaptcha = new AdvertWayApi($config['advertway_publickey'], $config['advertway_privatekey']);
            $html = $this->awcaptcha->getCaptchaWidget();
		}
		
		$template->assign_vars(array(
			'S_ADVERTWAY_AVAILABLE'		=> $this->is_available(),
			'ADVERTWAY_HTML'			=> $html,
			'S_TYPE'			        => $this->type,
            'S_CONFIRM_CODE'            => true,
		));
		
		return 'captcha_advertway_acp_demo.html';
	}

	function validate()
	{
		global $config, $db, $user;

		$error = '';
		$this->awcaptcha = new AdvertWayApi($config['advertway_publickey'], $config['advertway_privatekey']);
		
        if($this->challenge)
        {
            if(empty($this->solution))
            {
                $error = $user->lang['CONFIRM_CODE_WRONG'];
                return $error;
            }
            else
            {
                if(!$this->awcaptcha->validate())
                {
                    $error = $user->lang['CONFIRM_CODE_WRONG'];
                    return $error;
                }
            }
        }
        
        $this->solved = true;
        return false;
	}

}
?>
